@@ -3,7 +3,7 @@ BEGIN {
   $MooseX::Getopt::Strict::AUTHORITY = 'cpan:STEVAN';
 }
 BEGIN {
-  $MooseX::Getopt::Strict::VERSION = '0.32';
+  $MooseX::Getopt::Strict::VERSION = '0.34';
 }
 # ABSTRACT: only make options for attrs with the Getopt metaclass
 
@@ -83,11 +83,19 @@ Dagfinn Ilmari Mannsåker <ilmari@ilmari.org>
 
 Chris Prather <perigrin@cpan.org>
 
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Jonathan Swartz <swartz@pobox.com>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Infinity Interactive, Inc.
+This software is copyright (c) 2011 by Infinity Interactive, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
